#ifndef __EMITTED_VALIDATE_H
#define __EMITTED_VALIDATE_H

#include <bits/stdc++.h>

typedef void (*feedback_function)(const char*, ...);

const int EXITCODE_AC = 0;
const int EXITCODE_WA = 0;

// declare a constant to be used as user_out.
const std::string FILENAME_USER_OUTPUT = "user_out";
// declare a constant to be used as input.
const std::string FILENAME_INPUT = "input";

#define USAGE "./%s\n"
// we have to define USAGE as dummy because we don't want to modify the lib. too much.

std::ifstream judge_in, judge_ans;
// another ifstream must be used for user_out;
std::ifstream user_out;

char *feedbackdir = NULL;

void vreport_feedback(const char* msg, va_list pvar) {
    assert(stderr);
    vfprintf(stderr, msg, pvar);
}

void report_feedback(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
}

void judge_message(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
}

void judge_error(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
    assert(0);
}

// cleaning up.
void cleanup() {
    fflush(stderr);
    fclose(stderr);
    fflush(stdout);
    fclose(stdout);
    judge_in.close();
    user_out.close();
}

// write another function ``scoring()`` for ac or wa.
void scoring(double score) {
    fprintf(stdout, "%.f", score + 1e-9);
}

void accept() {
    scoring(100.);
    cleanup();
    exit(EXITCODE_AC);
}

void accept_with_score(double scorevalue) {
    scoring(scorevalue);
    cleanup();
    exit(EXITCODE_AC);
}

void wrong_answer(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
    scoring(0.);
    cleanup();
    exit(EXITCODE_WA);
}

void init_io() {
    judge_in.open(FILENAME_INPUT, std::ios_base::in);
    if(judge_in.fail()) {
        judge_error("failed to open input file.\n");
    }
    user_out.open(FILENAME_USER_OUTPUT, std::ios_base::in);
    if(user_out.fail()) {
        judge_error("failed to open user output file.\n");
    }
    judge_ans.open("answer", std::ios_base::in);
    if(judge_ans.fail()) {
        judge_error("failed to open answer file.\n");
    }
}
using namespace std;
#define nmax 25
bool r[nmax], d1[nmax], d2[nmax];
bool check(int i, int j, int n) {
    if (i < 1 || i > n)
        return 0;
    if (r[i]) return 0;
        r[i] = 1;
    if (d1[i + j]) return 0;
        d1[i + j] = 1;
    if (d2[n + i - j]) return 0;
        d2[n + i - j] = 1;
    return 1;
}
bool check(istream &inf, istream &ans, istream &ouf, feedback_function waf) {
    int n, a, o;
    ans >> a;
    if (!(ouf >> o))
        waf("Du lieu ra khong dung dinh dang.\n");
    if (a != o) {
        if (a == 0)
            waf("Sai. Khong co phuong an bo tri lau dai.\n");
        else
            waf("Sai. Co %d phuong an bo tri lau dai.\n", a);
    }
    if (a == 0) {
        judge_message("OK. Khong co phuong an bo tri lau dai!\n");
        return 1;
    }
    memset(r, 0, sizeof r);
    memset(d1, 0, sizeof d1);
    memset(d2, 0, sizeof d2);
    inf >> n;
    for (int i = 1; i <= n; i++) {
        if (!(ouf >> o))
            waf("Du lieu ra khong dung dinh dang.\n");
        if (!check(o, i, n))
            waf("Sai. Phuong an bo tri lau dai khong dung.\n");
    }
    string s;
    if (ouf >> s)
        waf("Du lieu ra khong dung dinh dang.\n");

    judge_message("OK. Co %d phuong an bo tri lau dai!\n", a);
        return 1;
}
#endif

int main(void) {
    init_io();
    check(judge_in, judge_ans, user_out, wrong_answer);
    accept();
}
